__version__ = "0.1.8"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.1.8)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'ac0283f1c9fa4d4d41508dfe12175227ee64da3a'
__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
__git_head_message__ = ''
__git_dirty_diff__ = ''